# encodertest
Test utilities for the skycoin encoder

[![Build Status](https://travis-ci.org/skycoin/encodertest.svg)](https://travis-ci.org/skycoin/encodertest)
[![GoDoc](https://godoc.org/github.com/skycoin/encodertest?status.svg)](https://godoc.org/github.com/skycoin/encodertest)
